---
args: [version, part]
title: Bump $part version to `v$version`
---

### Description

Ready to be merged into `main` branch, at the discretion of the maintainers, to bump the \$part part of the version number. Version bumps are scheduled daily and also triggered after releases. See the [`bump-versions` job documentation](https://github.com/kdeldycke/workflows?tab=readme-ov-file#githubworkflowschangelogyaml-jobs) for details.

### To bump version to `v\$version`

1. **Click `Ready for review`** button below, to get this PR out of `Draft` mode

2. **Click `Rebase and merge`** button below
